@@ -26,7 +26,7 @@ class USelenium():
         self.driver = ''
     
     
-    def initDriver(self, driverType, options=None, timeout=10):
+    def initDriver(self, driverType, options=None, downDir=None, timeout=10):
         '''
         方法名称： initDriver
             Driver初始化，区分driver浏览器，如：谷歌-chrome， 火狐-firefox，edge，ie等浏览器
@@ -38,18 +38,28 @@ class USelenium():
         '''
         try:
             if driverType == 'chrome':
-                if options != None:
+                if downDir != None:
                     option = webdriver.ChromeOptions()
-                    option.add_argument(options)
+                    options = {'profile.default_content_settings.popups':0,
+                           'download.default_directory': downDir
+                    }
+                    option.add_experimental_option('prefs', options)
                     self.driver = webdriver.Chrome(chrome_options=option)
                 else:
                     self.driver = webdriver.Chrome()
             if driverType == 'firefox':
-                if options != None:
-                    option = webdriver.FirefoxProfile(options)
-                    self.driver = webdriver.Chrome(firefox_options=option)
+                if downDir != None:
+                    fp = webdriver.FirefoxProfile()
+                    fp.set_preference('browser.download.manager.showWhenStarting',False)
+                    fp.set_preference('browser.download.folderList',2)  #设置Firefox的默认下载文件夹。0是桌面；1是“我的下载”；2是自定义。
+                    fp.set_preference('browser.download.dir', downDir)    #设置自定义路径时，定义的路径
+                    fp.set_preference('browser.helperApps.neverAsk.saveToDisk','text/plain')     #不询问下载路径；后面的参数为要下载页面的文件类型的值。
+#                     fp.set_preference("browser.helperApps.alwaysAsk.force", False);
+#                     option = webdriver.FirefoxProfile(options)
+                    
+                    self.driver = webdriver.Firefox(firefox_profile=fp)
                 else:
-                    self.driver = webdriver.Firefox(firefox_options=option)
+                    self.driver = webdriver.Firefox()
             if driverType == 'edge':
                 self.driver = webdriver.Edge()
             if driverType == 'ie':
@@ -1202,5 +1212,5 @@ class USelenium():
             print('关闭窗口失败')
             return False
         
-if __name__ == "__main__":
-    us = USelenium()
\ No newline at end of file
+# if __name__ == "__main__":
+#     us = USelenium()
\ No newline at end of file
